#ifndef _BSS_DATAMATRIX_READER_H_
#define _BSS_DATAMATRIX_READER_H_


/*
// Import/Export support
*/

#if defined(_MSC_VER) && defined(_BSS_DM_DLL)
#if defined(_BSS_DM_EXPORTS)
#define BSS_DLL __declspec(dllexport)
#else
#define BSS_DLL __declspec(dllimport)
#endif
#else
#define BSS_DLL
#endif

#ifdef __cplusplus
extern "C" {
#endif


/*
// Definitions of return codes 
*/

#define BSS_DM_OK               (0)
#define BSS_DM_NOTFOUND         (1)
#define BSS_DM_INVALIDARGS      (2)
#define BSS_DM_OUTOFMEMORY      (3)
#define BSS_DM_BADSYMBOL        (4)


/* 
// Structure for general barcode information
*/
typedef struct BSS_DataMatrixInfo_Struct
{
    int                 nCenterPosX;           /* Center (X) barcode position on the image    */
    int                 nCenterPosY;           /* Center (Y) barcode position on the image    */
    int                 nDataLength;           /* Length of barcode's data (in bytes)         */
    char*               pchData;               /* Pointer to barcode's data                   */
} bssDataMatrixInfo;


/* 
// Read DataMatrix barcode symbol on the image
*/
BSS_DLL int BSS_ReadDataMatrix
(
    const unsigned char* pImageData,           /* Pointer to image data                       */
    int                  nImageWidth,          /* The image width                             */
    int                  nImageHeight,         /* The image height                            */
    int                  nImageRowDist,        /* Distance between image's rows (in bytes)    */
    int                  nTryReadMultiple,     /* Try to read multiple barcodes on the image  */
    bssDataMatrixInfo**  ppDataMatrixInfo,     /* Pointer to array with barcodes' information */
    int*                 pnDataMatrixInfoCount /* Pointer to number of recognized symbol(s)   */
);

/* 
// Release allocated resources 
*/
BSS_DLL int BSS_ReleaseDataMatrixResults
(
    bssDataMatrixInfo*   pDataMatrixInfo,       /* Pointer to array with barcodes' information */
    int                  nDataMatrixInfoCount   /* Number of items in the array                */
);

#ifdef __cplusplus
}       /* extern "C" */
#endif

#endif /* _BSS_DATAMATRIX_READER_H_ */
